@@ -163,7 +163,7 @@ class _GSettingsTweak(Tweak):
         if 'uid' not in options:
             options['uid'] = key_name
         try:
-            self.settings = GSettingsSetting(schema_name=schema_name, schema_id=schema_id, **options)
+            self.settings = GSettingsSetting(schema_name=schema_name, schema_dir=schema_dir, schema_id=schema_id, **options)
             Tweak.__init__(self,
                 title,
                 options.get("description", self.settings.schema_get_description(key_name)),
@@ -404,7 +404,10 @@ class GSettingsTweakFontRow(Adw.ActionRow, _GSettingsTweak, _DependableMixin):
         try:
             font_desc = font_dialog.choose_font_finish(result)
 
+            self.settings.set_string(self.key_name, font_desc.to_string())
+
             self.font_desc = font_desc.copy()
+
             self._update_label()
         except GLib.GError as e:
             logging.debug("Error dismissing dialog", exc_info=e)
@@ -579,6 +582,7 @@ class FileChooserButton(Gtk.Button, GObject.Object):
         super().__init__()
         self._btn_content = Adw.ButtonContent(label=_("None"),
                                               icon_name="document-open-symbolic")
+        self._btn_content.props.can_shrink = True
         self.set_child(self._btn_content)
 
         self._mimetypes = mimetypes
